@@ -192,8 +192,8 @@ class RinnaiWaterHeater(object):
         self.__acquireToken()
 
         payload = ("{\r\n    \"query\": \"query GetUserByEmail($email: String, $sortDirection: ModelSortDirection, $filter: ModelRinnaiUserFilterInput, $limit: Int, $nextToken: String) "
-                   "{\\n  getUserByEmail(email: $email, sortDirection: $sortDirection, filter: $filter, limit: $limit, nextToken: $nextToken) {\\n    items {\\n      id\\n      name\\n      email\\n      "
-                   "country\\n      username\\n      firstname\\n      lastname\\n      devices {\\n        items {\\n          id\\n          thing_name\\n          device_name\\n          dealer_uuid\\n          "
+                   "{\\n  getUserByEmail(email: $email, sortDirection: $sortDirection, filter: $filter, limit: $limit, nextToken: $nextToken) {\\n    items {devices {\\n        "
+                   "items {\\n          id\\n          thing_name\\n          device_name\\n          dealer_uuid\\n          "
                    "city\\n          state\\n          street\\n          zip\\n          country\\n          firmware\\n          model\\n          dsn\\n          user_uuid\\n          connected_at\\n          "
                    "key\\n          lat\\n          lng\\n          address\\n          vacation\\n          createdAt\\n          updatedAt\\n          activity {\\n            clientId\\n            "
                    "serial_id\\n            timestamp\\n            eventType\\n          }\\n          shadow {\\n            heater_serial_number\\n            ayla_dsn\\n            "
@@ -241,16 +241,9 @@ class RinnaiWaterHeater(object):
 
         if r.status_code == 200:
             result = r.json()
-            data = result.get('data')
-            if data:
-                getUserByEmail = data.get('getUserByEmail')
-                if getUserByEmail:
-                    items = getUserByEmail.get('items')
-                    if items:
-                        devices = items.get('devices')
-                        if devices:
-                            device_items = devices.get('items')
-            return device_items
+            for items in result["data"]['getUserByEmail']['items']:
+                for k,v in items['devices'].items():
+                    return v
         else:
             r.raise_for_status()
 
